summaryrefslogtreecommitdiffstats
path: root/kplato/kpttask.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /kplato/kpttask.h
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kplato/kpttask.h')
-rw-r--r--kplato/kpttask.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kplato/kpttask.h b/kplato/kpttask.h
index cace7dcb..2d3776db 100644
--- a/kplato/kpttask.h
+++ b/kplato/kpttask.h
@@ -39,8 +39,8 @@ class DateTime;
*/
class Task : public Node {
public:
- Task(Node *tqparent = 0);
- Task(Task &task, Node *tqparent = 0);
+ Task(Node *parent = 0);
+ Task(Task &task, Node *parent = 0);
~Task();
/// Return task type. Can be Type_Task, Type_Summarytask ot Type_Milestone.
@@ -193,7 +193,7 @@ public:
/// Check if this node has any dependent child nodes.
bool isEndNode() const;
/// Check if this node has any dependent tqparent nodes
bool isStartNode() const;
/**
@@ -193,7 +193,7 @@ public:
/// Check if this node has any dependent child nodes.
bool isEndNode() const;
- /// Check if this node has any dependent tqparent nodes
+ /// Check if this node has any dependent parent nodes
bool isStartNode() const;
/**